import Vue from 'vue';
import VueRouter from 'vue-router';
import store from '@/store/index';
import { Notification } from 'element-ui';

Vue.use(VueRouter);

const routes = [
  {
    path: '/login',
    name: 'login',
    meta: { title: '登录', sub: '管理' },
    component: () => import('../views/login.vue'),
  },
  {
    path: '/register',
    name: 'register',
    meta: { title: '注册', sub: '管理' },
    component: () => import('../views/register.vue'),
  },
  {
    path: '/',
    meta: { title: '注教师遴选系统', sub: '管理' },
    component: () => import('../views/index.vue'),
  },
];

const router = new VueRouter({
  mode: 'history',
  base: process.env.NODE_ENV === 'development' ? '' : 'teachersel',
  routes,
});
router.beforeEach((to, form, next) => {
  store.commit('setUser');
  if (to.name === 'login' || to.name === 'register') {
    next();
    return;
  }
  let user = store.state.user;
  if (user) {
    if (user.type == process.env.VUE_APP_USER_TYPE) {
      console.log('已登录');
      next();
    } else {
      Notification({
        title: '请重新登陆',
        message: `原因:非当前端用户,需要重新登陆`,
        type: 'warning',
      });
      console.warn('非当前端用户,需要重新登陆');
      next({ name: 'login' });
    }
  }
  //下面是没登录的情况,需要跳转页面到用户未登录页
  else next({ name: 'login' });
});
export default router;
